#
# spec file for package systemd-default-settings
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define extra_version %{nil}

Name:           systemd-default-settings
URL:            https://github.com/openSUSE/systemd-default-settings
Version:        0.8
Release:        1.1
Summary:        Generic SUSE Customization of systemd defaults
License:        GPL-2.0-or-later
Group:          System/Base
Source0:        %{name}-%{version}%{extra_version}.tar.gz
BuildArch:      noarch
BuildRequires:  systemd-rpm-macros
Requires:       %{name}-branding = %{version}-%{release}

%description
This package overrides some of the upstream default settings which are
better suited for openSUSE or SLE distributions.

This package should not be installed alone but is supposed to be
pulled in by the branding package instead.

%package branding-SLE
Summary:        SLE Specific Customization of systemd defaults
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
Supplements:    packageand(%{name}:branding-SLE)
Provides:       %{name}-branding = %{version}-%{release}
Conflicts:      otherproviders(%{name}-branding)

%description branding-SLE
This package overrides some of the upstream default settings to make
them better suited for SLE distributions.

%package branding-openSUSE
Summary:        openSUSE Specific Customization of systemd defaults
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
Supplements:    packageand(%{name}:branding-openSUSE)
Provides:       %{name}-branding = %{version}-%{release}
Conflicts:      otherproviders(%{name}-branding)

%description branding-openSUSE
This package overrides some of the upstream default settings to make
them better suited for openSUSE distributions.

%package branding-upstream
Summary:        Restore upstream systemd defaults
Group:          System/Base
Provides:       %{name}-branding = %{version}-%{release}
Conflicts:      %{name}
Conflicts:      otherproviders(%{name}-branding)

%description branding-upstream
Installing this package restores some of the upstream default settings
by uninstalling all drop-ins shipped by %{name} and its branding sub
package.

%package branding-SLE-Micro
Summary:        SLE-Micro Specific Customization of systemd defaults
Group:          System/Base
Requires:       %{name} = %{version}-%{release}
Supplements:    packageand(%{name}:branding-SLE-Micro)
Provides:       %{name}-branding = %{version}-%{release}
Conflicts:      otherproviders(%{name}-branding)

%description branding-SLE-Micro
This package overrides some of the upstream default settings to make
them better suited for SLE-Micro distributions.

%prep
%setup -q -n %name-%{version}%{extra_version}

%build

%install
%make_install

# Convert early drop-ins into regular ones on Factory (1699) and ALP (1600). The
# removal of early drop-ins happens on these 2 distros only. SLE15/Leap15 (1500)
# still relies one them.
%if %{suse_version} >= 1600
find %{buildroot} -name __\*.conf -exec rename '.conf.d/__' '.conf.d/' {} \;
%endif

find %{buildroot} -name \*.d -type d -printf "%%%%dir /%%P\n" >SUSE.list
find %{buildroot} -name \*-defaults-SUSE.conf -printf "/%%P\n" >>SUSE.list
find %{buildroot} -name \*-defaults-SLE.conf -printf "/%%P\n" >SLE.list
find %{buildroot} -name \*-defaults-openSUSE.conf -printf "/%%P\n" >openSUSE.list
find %{buildroot} -name \*-defaults-SLE-Micro.conf -printf "/%%P\n" >SLE-Micro.list

%post
# Reloading PID1 is probably not enough as some changes will require
# service restarts or even a reboot. But it might be useful in a few
# cases so...
[ -x /usr/bin/systemctl ] &&
	/usr/bin/systemctl daemon-reload || :

%files -f SUSE.list
%defattr(-,root,root)

%files branding-SLE -f SLE.list
%defattr(-,root,root)

%files branding-openSUSE -f openSUSE.list
%defattr(-,root,root)

%files branding-upstream
%defattr(-,root,root)

%files branding-SLE-Micro -f SLE.list -f SLE-Micro.list
%defattr(-,root,root)

%changelog
* Fri Oct 20 2023 Franck Bui <fbui@suse.com>
- The usage of drop-ins is now the official way for configuring systemd and its
  various daemons on Factory/ALP. Hence the early drop-ins SUSE specific
  "feature" has been abandoned.
* Thu Oct 19 2023 Franck Bui <fbui@suse.com>
- Import 0.8
  f34372f User priority '26' for SLE-Micro
  c8b6f0a Revert "Convert more drop-ins into early ones"
* Tue Sep 21 2021 Franck Bui <fbui@suse.com>
- Import commit 6b8dde1d4f867aff713af6d6830510a84fad58d2
  6b8dde1 Convert more drop-ins into early ones
* Mon Feb 22 2021 Franck Bui <fbui@suse.com>
- Import 0.7
  2a61f77 Convert our configuration file dropins into 'early' ones
* Wed Feb 17 2021 Franck Bui <fbui@suse.com>
- Import 0.6
  d3fab7c Introduce SLE-Micro branding
* Thu Nov 26 2020 Franck Bui <fbui@suse.com>
- Fix typo introduced by the previous change (bsc#1179183)
* Thu Nov 19 2020 Franck Bui <fbui@suse.com>
- Issue a daemon-reload in %%post of the main package
* Thu Nov 19 2020 Franck Bui <fbui@suse.com>
- Import 0.5
  0c5e241 SLE: turn off RemoveIPC by default for logind (fate#320125)
  cb6914f SLE: restore ProtectHostname=no for udevd (bsc#1178374)
  7e332a6 Add a header in all each drop-ins
  465e1c7 Makefile: simplify 'archive' target
* Tue Oct 27 2020 Franck Bui <fbui@suse.com>
- Import 0.4
  a97bb54 Makefile: don't generate the rpm file lists anymore
  5473da6 Makefile: introduce 'archive' target
* Mon Oct 26 2020 Franck Bui <fbui@suse.com>
- Make sure the release number between the main and the branding
  packages match
* Fri Oct 23 2020 Franck Bui <fbui@suse.com>
- Import 0.3
  d299248 List drop-in directories in SUSE.list exclusively
  e4651a7 Disable memory accounting by default for all distros (jsc#PM-2229 jsc#PM-2230)
* Tue Oct 13 2020 Franck Bui <fbui@suse.com>
- Import 0.2
  cc4e951 timesyncd: add default ntp servers for SUSE and openSUSE distros
* Mon Oct 12 2020 Franck Bui <fbui@suse.com>
- Introduce "upstream" branding sub-package
  Installing this branding sub-package is supposed to restore upstream
  defaults by uninstalling all custom drop-ins installed by other
  branding sub-packages.
* Tue Oct  6 2020 Franck Bui <fbui@suse.com>
- Initial revision
